from setuptools import setup, find_packages

setup(
    name='FIT_Testcase_Sender',
    version='0.1.2',
    packages=find_packages(),
    description='A utility for sending scenarios via TCP/IP and checking their completion',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='suresofttech',
    author_email='sdhan@suresofttch.com',
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
    ],
    python_requires='>=3.6',
)


import socket
import json

class FIT_Remote:
    def __init__(self, ip_address: str, port: int) -> None:
        self.ip_address = ip_address
        self.port = port
    
    def excute_testcase(self, scenario_number: list) -> dict:
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
            scenario_number = {"ScenarioNo": scenario_number}
            sock.connect((self.ip_address, self.port))
            sock.sendall(json.dumps(scenario_number).encode('utf-8') + b'\n')
            return json.loads(sock.recv(1024).decode('utf-8'))       
    
    def is_testcase_result(self, scenario_response: dict) -> bool:
        return scenario_response['Result'] == 'Complete'

